@@ -46,6 +46,61 @@ static PyObject* setColor( PyObject* self, PyObject* args )
 
 }
 
+/*
+    Change alpha of surface
+    method:
+        0 alpha = alpha - shift
+        1 alpha = alpha
+        2 alpha = alpha * (shift/100)
+*/
+static PyObject* setAlpha( PyObject* self, PyObject* args )
+{
+    PyObject* py_surface = NULL;
+    Uint32 *pixels;
+    int w,h,x,y = 0;
+    Uint32 pixel;
+    SDL_PixelFormat *format = NULL;
+    int shift;
+    int method = 0;
+    double percent = 0;
+    Uint8 r,g,b,a;
+
+    PY_PARSEARGS_BEGIN
+        "Oi|i", &py_surface, &shift, &method
+    PY_PARSEARGS_END
+
+    getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
+    if( method == 1 ){
+        shift = clampUint8( shift );
+    }
+    if( method == 2 ){
+        percent = ((double)(shift))/100.0;
+    }
+
+    for( y = 0; y < h; y ++ ){
+        for( x = 0; x < w; x ++ ){
+            pixel = pixels[(y*w)+x];
+            SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
+            if(method == 0){
+                a = a + shift;
+                a = clampUint8( a );
+            }
+            if(method == 1){
+                a = shift;
+            }
+            if(method == 2){
+                a = a * percent;
+            }
+            pixel = SDL_MapRGBA( format, r, g, b, a );
+            pixels[ (y*w)+x ] = pixel;
+        }
+    }
+    
+    Py_INCREF(Py_None);
+    return Py_None;
+
+}
+
 /*
     Greyscale
     method:
@@ -407,7 +462,7 @@ static PyObject* colorize( PyObject* self, PyObject* args )
 
 
 /*
-    Replace pixels (hue == check_hue) with new_hue.
+    Apply per-pixel alpha mask on surface
 */
 static PyObject* alphaMask( PyObject* self, PyObject* args )
 {
@@ -420,14 +475,14 @@ static PyObject* alphaMask( PyObject* self, PyObject* args )
     Uint32 *pixels_mask;
     SDL_PixelFormat *format_mask = NULL;
 
-
-    Uint8 r,g,b,a;
+    Uint8 r,g,b,a,tmp_a;
     double hue,sat,val;
-    float alpha;
+    int method = 0;
+    float alpha,alpha2;
 
     PY_PARSEARGS_BEGIN
-        "OO",
-        &py_surface, &py_surface_mask
+        "OO|i",
+        &py_surface, &py_surface_mask, &method
     PY_PARSEARGS_END
     
     getSurfaceAttrs(py_surface_mask, &mw, &mh, &format_mask, &pixels_mask);
@@ -442,17 +497,39 @@ static PyObject* alphaMask( PyObject* self, PyObject* args )
             /* get mask pixel*/
             pixel = pixels_mask[(y*w)+x];
             SDL_GetRGBA( pixel, format_mask, &r, &g, &b, &a );
-            RGB2HSV( r,g,b, &hue, &sat, &val );
-            if(val >= 99.9) continue;
-            alpha = (float)(val/100.0);
+            if( method == 0 ){
+                RGB2HSV( r,g,b, &hue, &sat, &val );
+                if(val >= 99.9) continue;
+                alpha = (float)(val/100.0);
+                /* set pixel */
+                pixel = pixels[(y*w)+x];
+                SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
+                
+                tmp_a = (Uint8)(((float)a) * alpha );
+            } else if( method == 1 ){
+                tmp_a = a;
+                pixel = pixels[(y*w)+x];
+                SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
+            } else if( method == 2 ){
+                tmp_a = a;
+                pixel = pixels[(y*w)+x];
+                SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
+                /* alpha blend */
+                alpha = ((float) a) / 255.0;
+                alpha2 = ((float) tmp_a) / 255.0;
+                tmp_a = (alpha * alpha2) * 255;
+            } else if( method == 3 ){
+                tmp_a = a;/*mask alpha*/
+                pixel = pixels[(y*w)+x];
+                SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
+                if(tmp_a > 0){/* if mask alpha > 0 then set original alpha */
+                    tmp_a = a;
+                }
+            } else {
+                tmp_a = 255;
+            }
             
-            /* set pixel */
-            pixel = pixels[(y*w)+x];
-            SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
-            
-            a = (Uint8)(((float)a) * alpha );
-            
-            pixel = SDL_MapRGBA( format, r, g, b, a );
+            pixel = SDL_MapRGBA( format, r, g, b, tmp_a );
             pixels[ (y*w)+x ] = pixel;
 
         }
@@ -465,6 +542,7 @@ static PyObject* alphaMask( PyObject* self, PyObject* args )
 
 static PyMethodDef ColorMethods[] = {
     {"setColor", setColor, METH_VARARGS, "Set opaque pixels to color"},
+    {"setAlpha", setAlpha, METH_VARARGS, "Set alpha channel of surface"},
     
     {"hue", hue, METH_VARARGS, "Hue"},
     {"saturation", saturation, METH_VARARGS, "Change saturation of surface"},
