@@ -160,10 +160,10 @@ static PyObject* gradient( PyObject* self, PyObject* args )
     Uint32 *pixels = NULL;
 
     Uint32 pixel;
-    Uint8 color[3];
+    Uint8 color[4];
     Uint8 fcolor[4];
     Uint8 tcolor[4];
-    int x,y,i,q,w,h,dR,dG,dB,rows,cols;
+    int x,y,i,q,w,h,dR,dG,dB,dA,rows,cols;
     char vertical = 0;
     float ratio = 0.0;
     double nn,delta;
@@ -187,6 +187,7 @@ static PyObject* gradient( PyObject* self, PyObject* args )
     dR = (int)(tcolor[0]-fcolor[0]);
     dG = (int)(tcolor[1]-fcolor[1]);
     dB = (int)(tcolor[2]-fcolor[2]);
+    dA = (int)(tcolor[3]-fcolor[3]);
 
     rows = vertical?h:w;
     cols = vertical?w:h;
@@ -199,8 +200,9 @@ static PyObject* gradient( PyObject* self, PyObject* args )
         color[0] = (Uint8)( fcolor[0] + ( dR * nn ) );
         color[1] = (Uint8)( fcolor[1] + ( dG * nn ) );
         color[2] = (Uint8)( fcolor[2] + ( dB * nn ) );
+        color[3] = (Uint8)( fcolor[3] + ( dA * nn ) );
 
-        pixel = SDL_MapRGB( format, color[0], color[1], color[2] );
+        pixel = SDL_MapRGBA( format, color[0], color[1], color[2], color[3] );
         for( q = 0; q < cols; q ++ ){
             x = vertical?q:i;
             y = vertical?i:q;
