@@ -19,12 +19,22 @@
 
 static void getSurfaceAttrs(PyObject* py_surface, int *w, int *h, 
     SDL_PixelFormat** format, Uint32** pixels);
+
+
 SDL_Surface* createSurface( int width, int height );
+
 int HSV2RGB( double ih, double is, double iv, Uint8 *r, Uint8 *g, Uint8 *b );
+
 void RGB2HSV(Uint8 r, Uint8 g, Uint8 b, double *eh, double *es, double *ev);
+
 int RGB2HSL(Uint8 r, Uint8 g, Uint8 b, double *eh, double *es, double *el);
+
 int HSL2RGB(double eh, double es, double el, Uint8 *r, Uint8 *g, Uint8 *b);
 
+
+
+
+/* Get surface attributes format, size and pointer to pixels array */
 static void getSurfaceAttrs(PyObject* py_surface, int *w, int *h, 
     SDL_PixelFormat** format, Uint32** pixels)
 {
@@ -33,7 +43,54 @@ static void getSurfaceAttrs(PyObject* py_surface, int *w, int *h,
     *w = c_surface->surf->w;
     *h = c_surface->surf->h;
     *format = c_surface->surf->format;
-    *pixels = (Uint32 *)c_surface->surf->pixels;
+    //*surface = (SDL_Surface *)c_surface->surf;
+    *pixels = (Uint32 *) c_surface->surf->pixels;
+}
+
+
+
+/* Get pixel (from pygame surface.c) */
+static Uint32 getPixel(SDL_Surface* surface, int x, int y){
+    Uint8 *pixel;
+    Uint32 color;
+    Uint8 *pixels = (Uint8 *) surface->pixels;
+    SDL_PixelFormat *format = surface->format;
+
+    if(format->BytesPerPixel == 3){
+        pixel = ((Uint8 *) (pixels + y * surface->pitch) + x * 3);
+#if SDL_BYTEORDER == SDL_LIL_ENDIAN
+        color = (pixel[0]) + (pixel[1] << 8) + (pixel[2] << 16);
+#else
+        color = (pixel[2]) + (pixel[1] << 8) + (pixel[0] << 16);
+#endif
+    } else if(format->BytesPerPixel == 4){
+        color = *((Uint32 *) (pixels + y * surface->pitch) + x);
+    }    
+    return color;
+}
+
+/* Set pixel (from pygame surface.c) */
+static void setPixel(SDL_Surface* surface, int x, int y, Uint32 color){
+    SDL_PixelFormat *format = surface->format;
+    Uint8 *pixels = (Uint8 *) surface->pixels;
+    
+    Uint8 *byte_buf;
+
+    if(format->BytesPerPixel == 3){
+        byte_buf = (Uint8 *) (pixels + y * surface->pitch) + x * 3;
+#if (SDL_BYTEORDER == SDL_LIL_ENDIAN)
+        *(byte_buf + (format->Rshift >> 3)) = (Uint8) (color >> 16);
+        *(byte_buf + (format->Gshift >> 3)) = (Uint8) (color >> 8);
+        *(byte_buf + (format->Bshift >> 3)) = (Uint8) color;
+#else
+        *(byte_buf + 2 - (format->Rshift >> 3)) = (Uint8) (color >> 16);
+        *(byte_buf + 2 - (format->Gshift >> 3)) = (Uint8) (color >> 8);
+        *(byte_buf + 2 - (format->Bshift >> 3)) = (Uint8) color;
+#endif
+    } else if (format->BytesPerPixel == 4){
+
+        *((Uint32 *) (pixels + y * surface->pitch) + x) = color;
+    }
 }
 
 
