@@ -7,6 +7,7 @@ import time
 pygame.display.init()
 pygame.display.set_mode((1, 1))
 
+
 class Tester:
     def __init__(self, source_image, num=1):
         self.num = num
@@ -54,6 +55,7 @@ class Tester:
                 self.doTest(test)
 
     def doTest(self, name):
+        print "Test: %s" % name
         try:
             test = self.tests[name]
             source = test[3].copy()
@@ -90,14 +92,17 @@ class Tester:
                 print "%21s: %.1f ms" % (test, avgtime)
         print "%21s: %.1f ms" % ("Total time", count)
 
-source_rgb = pygame.image.load("source_rgb.png")
+source_rgb = pygame.image.load("source_rgb.png").convert()
 source_rgba = pygame.image.load("source_rgba.png")
 source_mask = pygame.image.load("source_mask.png")
+source_colorize = pygame.image.load("source_colorize.png")
 
 tester = Tester("source_rgb.png", 2)
+
 tester.addTests([
                 ("color.colorize", "modify-inplace",
-                 pgext.color.colorize, [200, 10, -10, 10], source_rgba),
+                 pgext.color.colorize, [120, 0, -30, 10], source_colorize),
+
                 ("color.greyscale1", "modify-inplace",
                  pgext.color.greyscale, []),
                 ("color.greyscale2", "modify-inplace",
@@ -115,8 +120,12 @@ tester.addTests([
 
                 ("color.setColor", "modify-inplace",
                  pgext.color.setColor, [(120, 0, 200)], source_rgba),
+                ("color.setAlpha", "modify-inplace",
+                 pgext.color.setAlpha, [40, 2], source_rgba),
                 ("color.alphaMask", "modify-inplace",
                  pgext.color.alphaMask, [source_mask]),
+                ("color.alphaMask2", "modify-inplace",
+                 pgext.color.alphaMask, [source_rgba, 1]),
 
                 ("filters.shadow", "modify-return",
                  pgext.filters.shadow, [(0, 0, 0), 5, 1, 0.9], source_rgba),
@@ -136,7 +145,7 @@ tester.addTests([
                 ("filters.gradient1", "make", pgext.filters.gradient,
                  [(200, 200), (100, 100, 200), (100, 200, 100), 0, 1.0]),
                 ("filters.gradient2", "make", pgext.filters.gradient,
-                 [(200, 200), (255, 0, 0), (0, 0, 255), 0, 0.3]),
+                 [(200, 200), (255, 0, 0, 0), (0, 0, 255, 255), 0, 0.3]),
                 ("filters.gradient3", "make", pgext.filters.gradient,
                  [(200, 200), (100, 0, 0), (0, 55, 55), 1, 1.0]),
                 ])
